#  tests for tensorflow-2.3.0-mkl_py37h3bad0a6_0 (this is a generated file);
print('===== testing package: tensorflow-2.3.0-mkl_py37h3bad0a6_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import tensorflow as tf
hello = tf.constant('Hello, TensorFlow!')
a = tf.constant(10)
b = tf.constant(32)
a + b
#  --- run_test.py (end) ---

print('===== tensorflow-2.3.0-mkl_py37h3bad0a6_0 OK =====');
print("import: 'tensorflow'")
import tensorflow

print("import: 'tensorboard'")
import tensorboard

